#define BUILD_NUMBER \
	"build-24696409"
#define BUILD_NUMBER_NUMERIC \
	24696409
#define BUILD_NUMBER_NUMERIC_STRING \
	"24696409"
#define PRODUCT_BUILD_NUMBER \
	"product-build-52586"
#define PRODUCT_BUILD_NUMBER_NUMERIC \
	52586
#define PRODUCT_BUILD_NUMBER_NUMERIC_STRING \
	"52586"
